%global cache /var/cache/man
%global gnulib_ver 20140202

Summary: Tools for searching and reading man pages
Name: man-db
Version: 2.13.1
Release: %mkrel 2
# GPLv2+ .. man-db
# GPLv3+ .. gnulib
License: GPLv2+ and GPLv3+
Group: System/Libraries
URL: https://www.nongnu.org/man-db/

Source0: https://download.savannah.gnu.org/releases/%{name}/%{name}-%{version}.tar.xz
Source1: man-db.crondaily
Source2: man-db.sysconfig
Source3: man-db-cache-update.service
Source4: man-db-restart-cache-update.service

Obsoletes: man < 2.0
Provides: man = %{version}
Provides: man-pages-reader = %{version}
# FPC exception for gnulib - copylib - https://fedorahosted.org/fpc/ticket/174
Provides: bundled(gnulib)

# for neqn:
#$ man dbus-binding-tool
#man: command exited with status 127: /usr/libexec/man-db/zsoelim | /usr/libexec/man-db/manconv -f UTF-8:ISO-8859-1 -t UTF-8//IGNORE | preconv -e UTF-8 | tbl | neqn -Tutf8 | nroff -mandoc -rLL=97n -rLT=97n -Tutf8
Requires: groff

Requires: coreutils, grep, groff-for-man, gzip, less
Requires: xz
BuildRequires: gdbm-devel
BuildRequires: gettext
BuildRequires: groff
BuildRequires: less
BuildRequires: pkgconfig(libpipeline) >= 1.5.0
BuildRequires: pkgconfig(zlib)
BuildRequires: po4a
# (tv) fix build:
BuildRequires: libtool

%description
The man-db package includes five tools for browsing man-pages:
man, whatis, apropos, manpath and lexgrog. man formats and displays
manual pages. whatis searches the manual page names. apropos searches the
manual page names and descriptions. manpath determines search path
for manual pages. lexgrog directly reads header information in
manual pages.

%package cron
Summary: Periodic update of man-db cache
Group: System/Libraries

Requires: %{name} = %{version}-%{release}
Requires: crontabs

BuildArch: noarch

%description cron
This package provides periodic update of man-db cache.

%prep
%autosetup -p1

%build
%configure \
    --with-sections="1 1p 8 2 3 3p 3pm 4 5 6 7 9 0p n l p o 1x 2x 3x 4x 5x 6x 7x 8x" \
    --disable-setuid --disable-cache-owner \
    --with-systemdsystemunitdir=no \
    --with-browser=elinks --with-lzip=lzip \
    --with-snapdir=/var/lib/snapd/snap \
    --with-override-dir=overrides \
    --with-systemdsystemunitdir=%{_unitdir} \
    --with-systemdtmpfilesdir=%{_tmpfilesdir}
# (tv) fix build:
cp /usr/share/libtool/build-aux/depcomp -a build-aux/
%make_build CC="%{__cc} %{optflags}"

%check
# ALL tests must succeed
make check

%install
%make_install prefix=%{_prefix}

# move the documentation to the relevant place
mv %{buildroot}%{_datadir}/doc/man-db/* ./

# remove zsoelim man page - part of groff package
rm %{buildroot}%{_datadir}/man/man1/zsoelim.1

# remove libtool archives
rm %{buildroot}%{_libdir}/man-db/*.la

# install cache directory
install -d -m 0755  %{buildroot}%{cache}

# install cron script for man-db creation/update
mkdir -p %{buildroot}%{_sysconfdir}/cron.daily
install -D -p -m 0755 %{SOURCE1} %{buildroot}%{_sysconfdir}/cron.daily/man-db.cron

# config for cron script
mkdir -p %{buildroot}%{_sysconfdir}/sysconfig
install -D -p -m 0644 %{SOURCE2} %{buildroot}%{_sysconfdir}/sysconfig/man-db

# config for tmpfiles.d
install -D -p -m 0644 init/systemd/man-db.conf %{buildroot}/usr/lib/tmpfiles.d/.

# man-db-cache-update.service and man-db-restart-cache-update.service
install -D -p -m 0644 %{SOURCE3} $RPM_BUILD_ROOT%{_unitdir}/man-db-cache-update.service
install -D -p -m 0644 %{SOURCE4} $RPM_BUILD_ROOT%{_unitdir}/man-db-restart-cache-update.service

%find_lang %{name} --with-man --all-name
%find_lang %{name}-gnulib

%pre
# stop and disable timer from previous builds
if [ -e /usr/lib/systemd/system/mandb.timer ]; then
    if test -d /run/systemd; then
        systemctl stop man-db.timer >/dev/null 2>&1 || :
        systemctl -q disable man-db.timer >/dev/null 2>&1 || :
    fi
fi

%post
# clear the old cache
%{__rm} -rf %{cache}/* >/dev/null 2>&1 || :

%transfiletriggerin -- %{_mandir}
# update cache
if [ -x /usr/bin/systemd-run -a -x /usr/bin/systemctl ]; then
    /usr/bin/systemd-run --no-block /usr/bin/systemctl start man-db-cache-update >/dev/null 2>&1 || :
fi

%transfiletriggerpostun -- %{_mandir}
# update cache
if [ -x /usr/bin/systemd-run -a -x /usr/bin/systemctl ]; then
    /usr/bin/systemd-run --no-block /usr/bin/systemctl start man-db-cache-update >/dev/null 2>&1 || :
fi

%files -f %{name}.lang -f %{name}-gnulib.lang
%license COPYING
%doc README.md man-db-manual.txt man-db-manual.ps ChangeLog NEWS.md
%config(noreplace) %{_sysconfdir}/man_db.conf
%config(noreplace) %{_sysconfdir}/sysconfig/man-db
%config(noreplace) %{_tmpfilesdir}/man-db.conf
%{_unitdir}/man-db.service
%{_unitdir}/man-db.timer
%{_unitdir}/man-db-cache-update.service
%{_unitdir}/man-db-restart-cache-update.service
%{_sbindir}/accessdb
%{_bindir}/man
%{_bindir}/whatis
%{_bindir}/apropos
%{_bindir}/man-recode
%{_bindir}/manpath
%{_bindir}/lexgrog
%{_bindir}/catman
%{_bindir}/mandb
%dir %{_libdir}/man-db
%{_libdir}/man-db/*.so
%dir %{_libexecdir}/man-db
%{_libexecdir}/man-db/globbing
%{_libexecdir}/man-db/manconv
%{_libexecdir}/man-db/zsoelim
# (tv) conflict with filesystem package:
#%%attr(2755,root,man) %%verify(not mtime) %%dir %%{cache}
# documentation and translation
%{_mandir}/man1/apropos.1*
%{_mandir}/man1/man-recode.1*
%{_mandir}/man1/lexgrog.1*
%{_mandir}/man1/man.1*
%{_mandir}/man1/manconv.1*
%{_mandir}/man1/manpath.1*
%{_mandir}/man1/whatis.1*
%{_mandir}/man5/manpath.5*
%{_mandir}/man8/accessdb.8*
%{_mandir}/man8/catman.8*
%{_mandir}/man8/mandb.8*
%lang(da)   %{_datadir}/man/da/man*/*
%lang(de)   %{_datadir}/man/de/man*/*
%lang(es)   %{_datadir}/man/es/man*/*
%lang(fr)   %{_datadir}/man/fr/man*/*
%lang(id)   %{_datadir}/man/id/man*/*
%lang(it)   %{_datadir}/man/it/man*/*
%lang(ja)   %{_datadir}/man/ja/man*/*
%lang(ko)	%{_datadir}/man/ko/man*/*
%lang(nl)   %{_datadir}/man/nl/man*/*
%lang(pl)   %{_datadir}/man/pl/man*/*
%lang(pt)       %{_datadir}/man/pt/man*/*
%lang(pt_BR) %{_datadir}/man/pt_BR/man*/*
%lang(ru)   %{_datadir}/man/ru/man*/*
%lang(sr)   %{_datadir}/man/sr/man*/*
%lang(sv)   %{_datadir}/man/sv/man*/*
%lang(tr)   %{_datadir}/man/tr/man*/*
%lang(zh_CN)   %{_datadir}/man/zh_CN/man*/*

%files cron
%config(noreplace) %{_sysconfdir}/cron.daily/man-db.cron
%config(noreplace) %{_sysconfdir}/sysconfig/man-db



%changelog
* Sun Jul 13 2025 wally <wally> 2.13.1-2.mga10
+ Revision: 2254412
- rebuild with fixed groff (mga#34459)
- enable tests again after they were mistakenly disabled just to get pkg to build

* Wed Jul 02 2025 daviddavid <daviddavid> 2.13.1-1.mga10
+ Revision: 2244003
- new version: 2.13.1
+ umeabot <umeabot>
- Mageia 10 Mass Rebuild

* Tue Jan 10 2023 luigiwalser <luigiwalser> 2.11.2-1.mga9
+ Revision: 1932093
- 2.11.2

* Fri Nov 25 2022 tv <tv> 2.11.1-1.mga9
+ Revision: 1911061
- Rebase to version 2.11.1
- Add Korean translations

* Mon Oct 17 2022 tv <tv> 2.11.0-1.mga9
+ Revision: 1897250
- Rebase to version 2.11.0

* Fri Mar 18 2022 luigiwalser <luigiwalser> 2.10.2-1.mga9
+ Revision: 1798910
- 2.10.2
- remove patches (fixed upstream)

* Fri Feb 11 2022 tv <tv> 2.10.1-1.mga9
+ Revision: 1773036
- Update to 2.10.1

* Tue Feb 09 2021 luigiwalser <luigiwalser> 2.9.4-1.mga9
+ Revision: 1675099
- 2.9.4

* Tue Jun 23 2020 luigiwalser <luigiwalser> 2.9.3-1.mga8
+ Revision: 1598803
- 2.9.3

* Tue Jun 02 2020 tv <tv> 2.9.2-1.mga8
+ Revision: 1589728
- 2.9.2

* Tue Mar 03 2020 tv <tv> 2.9.1-1.mga8
+ Revision: 1553326
- 2.9.1

* Sun Feb 16 2020 umeabot <umeabot> 2.8.7-2.mga8
+ Revision: 1534482
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Fri Oct 04 2019 tv <tv> 2.8.7-1.mga8
+ Revision: 1449173
- 2.8.7
- prioritize POSIX man pages over perl manuals (rhbz#1663919)

* Mon Jan 14 2019 luigiwalser <luigiwalser> 2.8.5-1.mga7
+ Revision: 1356286
- 2.8.5

* Thu Dec 20 2018 martinw <martinw> 2.8.4-3.mga7
+ Revision: 1343490
- add --no-block option to systemd-run in file triggers to avoid hang
  when triggered by service_harddrake during boot (mga#24037)

* Sun Sep 23 2018 umeabot <umeabot> 2.8.4-2.mga7
+ Revision: 1299448
- Mageia 7 Mass Rebuild

* Wed Aug 01 2018 tv <tv> 2.8.4-1.mga7
+ Revision: 1246561
- new release
- fix failure of man-db-cache-update service when configured not to run
  (rhbz#1526715, mga#21596)
- set group of /var/cache/man to root and drop setgid bit (rhbz#1515823)
- run cache update in a transient service using systemd-run
  (rhbz#1318058, mga#18426)

* Mon Jun 18 2018 rapsys <rapsys> 2.8.3-2.mga7
+ Revision: 1237813
- Trigger rebuild for libgdbm conflict

* Mon Apr 16 2018 kekepower <kekepower> 2.8.3-1.mga7
+ Revision: 1219491
- Update to version 2.8.3

* Wed Apr 04 2018 tv <tv> 2.8.2-1.mga7
+ Revision: 1215283
- new release

* Thu Mar 23 2017 tv <tv> 2.7.6.1-2.mga6
+ Revision: 1094573
- requires xz (thus fixing filetrigger faillure on early transactions)

* Wed Feb 22 2017 tv <tv> 2.7.6.1-1.mga6
+ Revision: 1087354
- suppress potential locale warning when installing
- new release
- set owner of man cache to root instead of man
- fix build

* Mon Dec 12 2016 wally <wally> 2.7.5-3.mga6
+ Revision: 1074385
- require groff for neqn

* Fri Feb 26 2016 luigiwalser <luigiwalser> 2.7.5-2.mga6
+ Revision: 979733
- rebuild with configure2_5x and make_install
+ umeabot <umeabot>
- Mageia 6 Mass Rebuild

* Fri Nov 13 2015 tv <tv> 2.7.5-1.mga6
+ Revision: 903018
- new release

* Sun Nov 01 2015 tv <tv> 2.7.4-1.mga6
+ Revision: 897052
- imported package man-db


* Sat Oct 31 2015 Thierry Vignaud <tv@mageia.org> 2.7.4-1.mga6
- import from FC
- explicitely link with libgdbm
